@@ -6,98 +6,99 @@ create.bspline.basis <- function (rangeval=NULL, nbasis=NULL,
 {
 #  This function creates a bspline functional data basis.
 #  Arguments
-#  RANGEVAL ... an array of length 2 containing the lower and upper
-#               boundaries for the rangeval of argument values,
-#               or a positive number, in which case command
-#               rangeval <- c(0, rangeval) is executed.
-#               the default is c(0,1)
-#  NBASIS   ... the number of basis functions.  This argument must be
-#               supplied, and must be a positive integer.
-#  NORDER   ... order of b-splines (one higher than their degree).  The
-#                 default of 4 gives cubic splines.
-#  BREAKS   ... also called knots, these are a non-decreasing sequence
-#               of junction points between piecewise polynomial segments.
-#               They must satisfy BREAKS[1] = RANGEVAL[1] and
-#               BREAKS[NBREAKS] = RANGEVAL[2], where NBREAKS is the total
-#               number of BREAKS.  There must be at least 2 BREAKS.
+#  RANGEVAL...an array of length 2 containing the lower and upper
+#             boundaries for the rangeval of argument values,
+#             or a positive number, in which case command
+#             rangeval <- c(0, rangeval) is executed.
+#             the default is c(0,1)
+#  NBASIS  ...the number of basis functions.  This argument must be
+#             supplied, and must be a positive integer.
+#  NORDER  ...order of b-splines (one higher than their degree).  The
+#             default of 4 gives cubic splines.
+#  BREAKS  ...also called knots, these are a non-decreasing sequence
+#             of junction points between piecewise polynomial segments.
+#             They must satisfy BREAKS[1] = RANGEVAL[1] and
+#             BREAKS[NBREAKS] = RANGEVAL[2], where NBREAKS is the total
+#             number of BREAKS.  There must be at least 2 BREAKS.
 #  There is a potential for inconsistency among arguments NBASIS, NORDER,
-#    and BREAKS since
+#  and BREAKS since
 #             NBASIS = NORDER + LENGTH(BREAKS) - 2
 #  An error message is issued if this is the case.  Although previous
 #  versions of this function attempted to resolve this inconsistency in
 #  various ways, this is now considered to be too risky.
-#  DROPIND  ... A vector of integers specifiying the basis functions to
-#               be dropped, if any.  For example, if it is required that
-#               a function be zero at the left boundary, this is achieved
-#               by dropping the first basis function, the only one that
-#               is nonzero at that point.
-#  QUADVALS .. A NQUAD by 2 matrix.  The firs t column contains quadrature
-#                points to be used in a fixed point quadrature.  The second
-#                contains quadrature weights.  For example, for (Simpson"s
-#                rule for (NQUAD = 7, the points are equally spaced and the
-#                weights are delta.*[1, 4, 2, 4, 2, 4, 1]/3.  DELTA is the
-#                spacing between quadrature points.  The default is
-#                matrix("numeric",0,0).
-#  VALUES  ... A list, with entries containing the values of
-#                the basis function derivatives starting with 0 and
-#                going up to the highest derivative needed.  The values
-#                correspond to quadrature points in QUADVALS and it is
-#                up to the user to decide whether or not to multiply
-#                the derivative values by the square roots of the
-#                quadrature weights so as to make numerical integration
-#                a simple matrix multiplication.
-#                Values are checked against QUADVALS to ensure the correct
-#                number of rows, and against NBASIS to ensure the correct
-#                number of columns.
-#                The default value of is VALUES is vector("list",0).
-#                VALUES contains values of basis functions and derivatives at
-#                quadrature points weighted by square root of quadrature weights.
-#                These values are only generated as required, and only if slot
-#                QUADVALS is not matrix("numeric",0,0).
-#  BASISVALUES ... A vector of lists, allocated by code such as
-#                vector("list",1).
-#                This field is designed to avoid evaluation of a
-#                basis system repeatedly at a set of argument values.
-#                Each list within the vector corresponds to a specific set
-#                of argument values, and must have at least two components,
-#                which may be tagged as you wish.
-#                The first component in an element of the list vector contains the
-#                argument values.
-#                The second component in an element of the list vector
-#                contains a matrix of values of the basis functions evaluated
-#                at the arguments in the first component.
-#                The third and subsequent components, if present, contain
-#                matrices of values their derivatives up to a maximum
-#                derivative order.
-#                Whenever function getbasismatrix is called, it checks
-#                the first list in each row to see, first, if the number of
-#                argument values corresponds to the size of the first dimension,
-#                and if this test succeeds, checks that all of the argument
-#                values match.  This takes time, of course, but is much
-#                faster than re-evaluation of the basis system.  Even this
-#                time can be avoided by direct retrieval of the desired
-#                array.
-#                For example, you might set up a vector of argument values
-#                called "evalargs" along with a matrix of basis function
-#                values for these argument values called "basismat".
-#                You might want too use tags like "args" and "values",
-#                respectively for these.  You would then assign them
-#                to BASISVALUES with code such as
-#                  basisobj$basisvalues <- vector("list",1)
-#                  basisobj$basisvalues[[1]] <-
+#  DROPIND ...A vector of integers specifiying the basis functions to
+#             be dropped, if any.  For example, if it is required that
+#             a function be zero at the left boundary, this is achieved
+#             by dropping the first basis function, the only one that
+#             is nonzero at that point.
+#  QUADVALS...A NQUAD by 2 matrix.  The firs t column contains quadrature
+#             points to be used in a fixed point quadrature.  The second
+#             contains quadrature weights.  For example, for (Simpson"s
+#             rule for (NQUAD = 7, the points are equally spaced and the
+#             weights are delta.*[1, 4, 2, 4, 2, 4, 1]/3.  DELTA is the
+#             spacing between quadrature points.  The default is
+#             matrix("numeric",0,0).
+#  VALUES ... A list, with entries containing the values of
+#             the basis function derivatives starting with 0 and
+#             going up to the highest derivative needed.  The values
+#             correspond to quadrature points in QUADVALS and it is
+#             up to the user to decide whether or not to multiply
+#             the derivative values by the square roots of the
+#             quadrature weights so as to make numerical integration
+#             a simple matrix multiplication.
+#             Values are checked against QUADVALS to ensure the correct
+#             number of rows, and against NBASIS to ensure the correct
+#             number of columns.
+#             The default value of is VALUES is vector("list",0).
+#             VALUES contains values of basis functions and derivatives at
+#             quadrature points weighted by square root of quadrature weights.
+#             These values are only generated as required, and only if slot
+#             QUADVALS is not matrix("numeric",0,0).
+#  BASISVALUES...A vector of lists, allocated by code such as
+#             vector("list",1).
+#             This field is designed to avoid evaluation of a
+#             basis system repeatedly at a set of argument values.
+#             Each list within the vector corresponds to a specific set
+#             of argument values, and must have at least two components,
+#             which may be tagged as you wish.
+#             The first component in an element of the list vector contains the
+#             argument values.
+#             The second component in an element of the list vector
+#             contains a matrix of values of the basis functions evaluated
+#             at the arguments in the first component.
+#             The third and subsequent components, if present, contain
+#             matrices of values their derivatives up to a maximum
+#             derivative order.
+#             Whenever function getbasismatrix is called, it checks
+#             the first list in each row to see, first, if the number of
+#             argument values corresponds to the size of the first dimension,
+#             and if this test succeeds, checks that all of the argument
+#             values match.  This takes time, of course, but is much
+#             faster than re-evaluation of the basis system.  Even this
+#             time can be avoided by direct retrieval of the desired
+#             array.
+#             For example, you might set up a vector of argument values
+#             called "evalargs" along with a matrix of basis function
+#             values for these argument values called "basismat".
+#             You might want too use tags like "args" and "values",
+#             respectively for these.  You would then assign them
+#             to BASISVALUES with code such as
+#               basisobj$basisvalues <- vector("list",1)
+#               basisobj$basisvalues[[1]] <-
 #                               list(args=evalargs, values=basismat)
-#  NAMES  ...    Either a character vector of length NABASIS
-#                or a single character string to which NORDER, "." and
-#                1:NBASIS are appended by the command
-#                   paste(names, norder, ".", 1:nbreaks, sep="").
-#                For example, if norder = 4, this defaults to
-#                        'bspl4.1', 'bspl4.2', ... .
+#  NAMES ...  Either a character vector of length NABASIS
+#             or a single character string to which NORDER, "." and
+#             1:NBASIS are appended by the command
+#                paste(names, norder, ".", 1:nbreaks, sep="").
+#             For example, if norder = 4, this defaults to
+#                     'bspl4.1', 'bspl4.2', ... .
 #  Returns
-#  BASISFD  ... a functional data basis object
+#  BASISFD ...a functional data basis object
 
+#  Last modified July 1, 2012 by Spencer Graves to allow nonnumeric rangeval
 #  Last modified  7 May 2012 by Jim Ramsay
 
-#  -----------------------------------------------------------------------------
+#  -------------------------------------------------------------------------
 #  Default basis for missing arguments:  A B-spline basis over [0,1] of
 #    of specified norder with norder basis functions.
 #    norder = 1 = one basis function = constant 1
@@ -110,7 +111,7 @@ create.bspline.basis <- function (rangeval=NULL, nbasis=NULL,
 #    norder = 3 = three basis functions:  x^2, x-(x-.5)^2, (x-1)^2
 #    norder = 4 = default = 4 basis functions
 #      = the simplest cubic spline basis
-#  -----------------------------------------------------------------------------
+#  -------------------------------------------------------------------------
 
   type        <- "bspline"
 
@@ -129,15 +130,19 @@ create.bspline.basis <- function (rangeval=NULL, nbasis=NULL,
 #    return(basisobj)
 #  }
 
-#  -----------------------------------------------------------------------------
+#  ------------------------------------------------------------------------
 #                     Set up non-default basis
-#  -----------------------------------------------------------------------------
+#  ------------------------------------------------------------------------
 
 ##
 ## 1.  check RANGEVAL
 ##
 #  1.1.  First check breaks is either NULL
 #        or is numeric with positive length
+#  Breaks <- breaks
+  op <- options(warn=-1)
+  Breaks <- as.numeric(breaks)
+  options(op)
   if(!is.null(breaks)){
     if(is.numeric(breaks)){
       if(length(breaks)<1)breaks <- NULL
@@ -146,35 +151,51 @@ create.bspline.basis <- function (rangeval=NULL, nbasis=NULL,
       if(any(is.infinite(breaks)))
         stop('breaks contains Infs;  not allowed.')
     }
-    else
-      stop("breaks must be numeric;  class(breaks) = ", class(breaks))
+    else {
+#     suppress warning if NAs generated
+#      op <- options(warn=-1)
+#      Breaks <- as.numeric(breaks)
+#      options(op)
+      nNA <- sum(is.na(Breaks))
+      if(nNA>0)
+        stop("as.numeric(breaks) contains ", nNA,
+             ' NA', c('', 's')[1+(nNA>1)],
+             ';  class(breaks) = ', class(breaks))
+    }
   }
 #
-  {
-    if(length(rangeval)<1) {
-      if(is.null(breaks))
-        rangeval <- 0:1
-      else{
-        rangeval <- range(breaks)
-        if(diff(rangeval)==0)
-          stop('diff(range(breaks))==0;  not allowed.')
-      }
+#  Rangeval <- rangeval
+  op <- options(warn=-1)
+  Rangeval <- as.numeric(rangeval)
+  options(op)
+  if(length(rangeval)<1) {
+    if(is.null(breaks)) {
+      rangeval <- 0:1
+    } else{
+      rangeval <- range(breaks)
+      if(diff(rangeval)==0)
+        stop('diff(range(breaks))==0;  not allowed.')
     }
-    else
-      if(!is.numeric(rangeval))
-        stop('rangeval must be numeric;  class(rangeval) = ',
-             class(rangeval) )
-    if(length(rangeval) == 1){
+  } else {
+#    op <- options(warn=-1)
+#    rangeval <- as.numeric(rangeval)
+#    options(op)
+    nNAr <- sum(is.na(Rangeval))
+    if(nNAr>0)
+      stop('as.numeric(rangeval) contains ', nNAr,
+           ' NA', c('', 's')[1+(nNAr>1)],
+           ';  class(rangeval) = ', class(rangeval) )
+  }
+  if(length(rangeval) == 1){
       if(rangeval <= 0)
         stop("'rangeval' a single value that is not positive, is ",
              rangeval)
       rangeval = c(0,rangeval)
-    }
   }
 #  if (!rangechk(rangeval)) stop("Argument 'rangeval' is not correct.")
-  if(!is.vector(rangeval))
-    stop('rangeval is not a vector;  class(rangeval) = ',
-         class(rangeval))
+#  if(!is.vector(rangeval))
+#    stop('rangeval is not a vector;  class(rangeval) = ',
+#         class(rangeval))
 # rangeval too long ???
   if(length(rangeval)>2){
     if(!is.null(breaks))
